@@ -35,8 +35,7 @@ Usage::
 """
 from typing import Generic, Iterator, TypeVar
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .type_defs import (
     ListClusterOperationsResponseTypeDef,
@@ -72,7 +71,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class ListClusterOperationsPaginator(Boto3Paginator):
+class ListClusterOperationsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kafka.html#Kafka.Paginator.ListClusterOperations)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators/#listclusteroperationspaginator)
@@ -87,7 +86,7 @@ class ListClusterOperationsPaginator(Boto3Paginator):
         """
 
 
-class ListClustersPaginator(Boto3Paginator):
+class ListClustersPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kafka.html#Kafka.Paginator.ListClusters)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators/#listclusterspaginator)
@@ -102,7 +101,7 @@ class ListClustersPaginator(Boto3Paginator):
         """
 
 
-class ListClustersV2Paginator(Boto3Paginator):
+class ListClustersV2Paginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kafka.html#Kafka.Paginator.ListClustersV2)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators/#listclustersv2paginator)
@@ -121,7 +120,7 @@ class ListClustersV2Paginator(Boto3Paginator):
         """
 
 
-class ListConfigurationRevisionsPaginator(Boto3Paginator):
+class ListConfigurationRevisionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kafka.html#Kafka.Paginator.ListConfigurationRevisions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators/#listconfigurationrevisionspaginator)
@@ -136,7 +135,7 @@ class ListConfigurationRevisionsPaginator(Boto3Paginator):
         """
 
 
-class ListConfigurationsPaginator(Boto3Paginator):
+class ListConfigurationsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kafka.html#Kafka.Paginator.ListConfigurations)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators/#listconfigurationspaginator)
@@ -151,7 +150,7 @@ class ListConfigurationsPaginator(Boto3Paginator):
         """
 
 
-class ListKafkaVersionsPaginator(Boto3Paginator):
+class ListKafkaVersionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kafka.html#Kafka.Paginator.ListKafkaVersions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators/#listkafkaversionspaginator)
@@ -166,7 +165,7 @@ class ListKafkaVersionsPaginator(Boto3Paginator):
         """
 
 
-class ListNodesPaginator(Boto3Paginator):
+class ListNodesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kafka.html#Kafka.Paginator.ListNodes)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators/#listnodespaginator)
@@ -181,7 +180,7 @@ class ListNodesPaginator(Boto3Paginator):
         """
 
 
-class ListScramSecretsPaginator(Boto3Paginator):
+class ListScramSecretsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/kafka.html#Kafka.Paginator.ListScramSecrets)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_kafka/paginators/#listscramsecretspaginator)
